import { Awareness } from 'y-protocols/awareness';

/**
 * Represents presence object that can be associated to a user
 */
interface Presence {
    [x: string]: any;
}
/**
 * Represents a user connected in the room
 */
interface User<T> {
    /**
     * The client id associated to the user
     */
    readonly id: number;
    /**
     * The user presence
     */
    readonly presence: T;
}

declare function createPresenceStore<T extends Presence>(awareness: Awareness, initialPresence: T): {
    awareness: Awareness;
    getSnapshot: () => readonly User<T>[];
    setPresence: (presence: T) => void;
    subscribe: (callback: () => void) => () => void;
    destroy: () => void;
};

declare function usePresenceStore<T extends Presence, Selection>(store: ReturnType<typeof createPresenceStore<T>>, selector: (state: ReturnType<typeof store.getSnapshot>) => Selection, equalityFn?: (a: Selection, b: Selection) => boolean): [Selection, typeof store.setPresence];

export { Presence, User, createPresenceStore, usePresenceStore };
